@@ -310,6 +310,108 @@ YAHOO.crud.load_livegrid_by_id = function(id) {
     }
 }
 
+YAHOO.crud.livegrid_form = function(args) {
+    Logger(args);
+    var tab = YAHOO.crud.TABS[args.index];
+    Logger(tab);
+    var formId = 'livegrid' + args.index + '-form';
+
+    // fetch the html and insert it
+    var req = YAHOO.util.Connect.asyncRequest('GET', args.form,
+        {
+            success: function(o) {
+                if (o.responseText !== undefined) {
+                    var Dom = YAHOO.util.Dom;
+                    Dom.get(formId).innerHTML = o.responseText;
+                    
+                    // set form values
+                    var cmap     = tab.grid.opts.foreign.column_map;
+                    var newForm  = Dom.getElementsByClassName(
+                        'crud',
+                        'form',
+                        Dom.get(formId)
+                    )[0];
+                    //Logger(newForm);
+                    var thisOid = tab.grid.opts.parent.oid;
+                    var thisOidLabel = tab.grid.opts.parent.oidLabel;
+                    var saveButton, resetButton;
+                    var cancelButton = document.createElement('button');
+                    cancelButton.innerHTML = 'Cancel';
+                    Dom.addClass( cancelButton, 'button' );
+                    
+                    // want to hide the input field for thisOid
+                    // and any related autocomplete.
+                    for(var i=0; i<newForm.elements.length; i++) {
+                        var el = newForm.elements[i];
+                        if (el.name == cmap[0] || el.name == ('ac_' + cmap[0])) {
+                            el.parentNode.innerHTML = thisOidLabel + 
+                                '<input type="hidden" name="' + cmap[0] + '" value="' + thisOid + '" />';
+                            continue;
+                        }
+                        if (el.value == 'Save') {
+                            saveButton = el;
+                            //Logger("found Save button");
+                            continue;
+                        }
+                        if (el.value == 'Reset') {
+                            resetButton = el;
+                            //Logger("found Reset button");
+                            continue;
+                        }
+                    }
+                    
+                    // add a Cancel button
+                    //Logger(resetButton);
+                    if(Dom.insertAfter(cancelButton, resetButton)) {
+                    
+                        //Logger("insert Cancel button");
+                    
+                        YAHOO.util.Event.on(cancelButton, 'click', 
+                         function(e) { Dom.get(formId).innerHTML = '' });
+                         
+                        //Logger("set Cancel button");
+                    }
+                    
+                    // hijack the save button so we don't actually leave this page.
+                    
+                    YAHOO.util.Connect.setForm(newForm);
+                    
+                    // can't seem to use Event here.                    
+                    newForm.onsubmit = function(e) { return false };
+                    
+                    //Logger("set form");
+                    
+                    var respHandler = {
+                      success: function(o) {
+                        // reload the grid
+                        tab.grid.panel.store.reload();
+                        Dom.get(formId).innerHTML = '';
+                      },
+                      failure: function(o) {
+                        //YAHOO.crud.handleXHRFailure(o);
+                        alert("Error! Check that the value is not already set for this record.");
+                      }
+                    };
+                    
+                    YAHOO.util.Event.on(saveButton, 'click', function(e) {
+                        var uri = newForm.action + '?cxc-fmt=json';
+                        //alert("uri = " + uri);
+                        YAHOO.util.Connect.asyncRequest('POST', uri, respHandler);
+                    });
+
+                }
+                else {
+                    alert("unknown server error");
+                }
+            },
+            failure: function(o) {
+                YAHOO.crud.handleXHRFailure(o);
+            }
+        }
+    );
+
+}
+
 Ext.namespace('Ext.ux'); // livegrid js requires
 
 if (typeof USE_LIVEGRID_FILTERS != 'undefined') {
@@ -571,8 +673,14 @@ YAHOO.crud.new_livegrid = function(index) {
     //Logger(filters);
     
     var colModel = new Ext.grid.ColumnModel(column_defs);
-    // 240 is left menu width plus padding
-    var colAvgWidth = (document.body.clientWidth - 240) / opts.nVisible;
+    // 260 is left menu width plus padding
+    var winWidth = document.body.clientWidth;
+    var colAvgWidth = (winWidth - 260) / opts.nVisible;
+    
+    //Logger("winWidth = " + winWidth);
+    //Logger("avgWidth = " + colAvgWidth);
+    //Logger("nVisible = " + opts.nVisible);
+    
     colModel.defaultWidth = colAvgWidth;
     gridopts = {
         'el'             : opts.div_id,
@@ -888,7 +996,26 @@ YAHOO.crud.handle_related_livegrid_click = function(args) {
         return;
     }
     else {
-        window.location.href = args.url + args.rec.id + '/' + args.action;
+        var tab = YAHOO.crud.TABS[args.index];
+        //Logger(tab);
+        //Logger(args);
+        var uri;
+        if (args.m2m_url != '/') {
+            uri = args.m2m_url + args.rec.id + '/' + args.action;
+        }
+        else {
+            uri = args.url + args.rec.id + '/' + args.action;
+        }
+        
+        //Logger(uri);
+        //return;
+        
+        if (args.action == 'livegrid_edit_form') {
+            YAHOO.crud.livegrid_form({'index':args.index, 'form':uri});
+        }
+        else {
+            window.location = uri;
+        }
     }
 }
     
@@ -900,7 +1027,7 @@ YAHOO.crud.redirect_location = function(args) {
     var pk       = pk_vals.join(';;');
     var newurl   = args.url + pk + '/' + args.action;
     //Logger(newurl);
-    window.location.href = newurl;
+    window.location = newurl;
 }
         
 
